pub enum ValidationError {
DuplicateVariant,
DuplicateExtension,
MultipleExtendedLanguageSubtags,
PrimaryLanguageNotInRegistry,
ExtendedLanguageNotInRegistry,
ScriptNotInRegistry,
RegionNotInRegistry,
VariantNotInRegistry,
WrongExtendedLanguagePrefix,
WrongVariantPrefix,
}Expand description
Errors returned by the LanguageTag validation
Variants
DuplicateVariant
The same variant subtag is only allowed once in a tag.
DuplicateExtension
The same extension subtag is only allowed once in a tag before the private use part.
only one extended language subtag is allowed
PrimaryLanguageNotInRegistry
The primary language is not in the IANA Language Subtag Registry
ExtendedLanguageNotInRegistry
The extended language is not in the IANA Language Subtag Registry
ScriptNotInRegistry
The script is not in the IANA Language Subtag Registry
RegionNotInRegistry
The region is not in the IANA Language Subtag Registry
VariantNotInRegistry
A variant is not in the IANA Language Subtag Registry
WrongExtendedLanguagePrefix
The primary language is not the expected extended language prefix from the IANA Language Subtag Registry
WrongVariantPrefix
The language tag has not one of the expected variant prefix from the IANA Language Subtag Registry